CREATE INDEX "$SCHEMA$"."PT_AUTO_DEL_PID" ON "$SCHEMA$"."PROCESS"("PT_AUTO_DEL_PERIOD", "PT_PID") $

CREATE INDEX "$SCHEMA$"."PI_COMP_PTID_PIID" ON "$SCHEMA$"."PROCESS_INST"("PI_COMPLETE_TIME", "PI_PROCESS_PTID", "PI_PIID") $

CREATE INDEX "$SCHEMA$"."PI_STATE_AIID" ON "$SCHEMA$"."PROCESS_INST"("PI_STATE", "PI_PARENT_AIID") $
 
RENAME TABLE "$SCHEMA$"."EVENTS" TO EVENTS_BACK $

DROP INDEX "$SCHEMA$"."EVENT_CONTEXTID" $

CREATE TABLE "$SCHEMA$"."EVENTS"(
"EVENTID" CHAR(16) FOR BIT DATA NOT NULL,
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"EVENT_TIME" DECIMAL(16,0) NOT NULL,
"EVENT_CODE" INTEGER NOT NULL,
"CONTEXTID" CHAR(16) FOR BIT DATA NOT NULL,
"ENGINETYPE" VARCHAR(75) NOT NULL,
"ENGINEID" CHAR(16) FOR BIT DATA NOT NULL,
"EVENT_TIME_FRAC" INTEGER NOT NULL,
"SHORT_DATA" VARCHAR(1900) FOR BIT DATA,
CONSTRAINT "PK_EVENTS" PRIMARY KEY ("EVENTID"),
CONSTRAINT "EVENT_QUEUEID" UNIQUE("QUEUEID", "EVENT_SEQ")
) IN $TABLESPACE$ $


CREATE INDEX "$SCHEMA$"."EVENT_CONTEXTID" ON "$SCHEMA$"."EVENTS"("QUEUEID", "CONTEXTID") $

CREATE TABLE "$SCHEMA$"."EVENT_DATA"(
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"DATA_SEQ" INTEGER NOT NULL,
"DATA" VARCHAR(1900) FOR BIT DATA,
CONSTRAINT "PK_EVENT_DATA" PRIMARY KEY ("QUEUEID", "EVENT_SEQ", "DATA_SEQ")
) IN $TABLESPACE$ $

DROP TABLE "$SCHEMA$"."DELAYED_EVENTS" $

CREATE TABLE "$SCHEMA$"."DELAYED_EVENTS"(
"EVENTID" CHAR(16) FOR BIT DATA NOT NULL,
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"EVENT_TIME" DECIMAL(16,0) NOT NULL,
"EVENT_CODE" INTEGER NOT NULL,
"CONTEXTID" CHAR(16) FOR BIT DATA NOT NULL,
"ENGINETYPE" VARCHAR(75) NOT NULL,
"ENGINEID" CHAR(16) FOR BIT DATA NOT NULL,
"EVENT_TIME_FRAC" INTEGER NOT NULL,
"SHORT_DATA" VARCHAR(1900) FOR BIT DATA,
"TRIAL_NUMBER" INTEGER DEFAULT 0 NOT NULL,
CONSTRAINT "PK_DEVENTS" PRIMARY KEY ("EVENTID"),
CONSTRAINT "DELAYED_QUEUEID" UNIQUE("QUEUEID", "EVENT_SEQ", "TRIAL_NUMBER")
) IN $TABLESPACE$ $


CREATE INDEX "$SCHEMA$"."DELAYED_CONTEXTID" ON "$SCHEMA$"."DELAYED_EVENTS"("CONTEXTID") $

RENAME TABLE "$SCHEMA$"."LOCK_TABLE" TO EB_SYNC_TABLE $

CREATE TABLE "$SCHEMA$"."MQWF_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) IN $TABLESPACE$ $


CREATE TABLE "$SCHEMA$"."WMQI_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) IN $TABLESPACE$ $


CREATE TABLE "$SCHEMA$"."ICS_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) IN $TABLESPACE$ $


CREATE TABLE "$SCHEMA$"."CLEANUP_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) IN $TABLESPACE$ $


CREATE TABLE "$SCHEMA$"."NOTIFY_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) IN $TABLESPACE$ $


CREATE TABLE "$SCHEMA$"."CXFLOWEVENTRECORDS"(
"SEQUENCENUMBER" DECIMAL(16,0) NOT NULL,
"EVENT" VARCHAR(255) NOT NULL,
"MONITORFLOWID" VARCHAR(255) NOT NULL,
"OUTBOUNDFLOWID" VARCHAR(255) NOT NULL,
"TIMESTAMP" DECIMAL(16,0) NOT NULL,
"COMPONENTNAME" VARCHAR(80) NOT NULL,
"COMPONENTTYPE" INTEGER,
CONSTRAINT "EVENTINDEX" UNIQUE("SEQUENCENUMBER")
) IN $TABLESPACE$ $


CREATE TRIGGER "$SCHEMA$"."CX_INST" NO CASCADE BEFORE INSERT ON "$SCHEMA$"."CXFLOWEVENTRECORDS"
REFERENCING NEW AS NEW_REC FOR EACH ROW 
MODE DB2SQL BEGIN ATOMIC
SET NEW_REC.TIMESTAMP = (1000. * (((DAYS(CURRENT TIMESTAMP) - DAYS('1970-01-01')) * 86400.) + MIDNIGHT_SECONDS(CURRENT TIMESTAMP))) + (MICROSECOND(CURRENT TIMESTAMP)/1000);
END $
 
ALTER TABLE "$SCHEMA$"."PROCESS_MODEL" ADD PM_LAST_UPDATED DECIMAL(16,0) DEFAULT 0 $

INSERT INTO $SCHEMA$.SYS_PROPERTIES VALUES('monitor.eventProcessor.count', '1') $
