CREATE INDEX "$SCHEMA$"."PT_AUTO_DEL_PID" ON "$SCHEMA$"."PROCESS"("PT_AUTO_DEL_PERIOD", "PT_PID");

CREATE INDEX "$SCHEMA$"."PI_COMP_PTID_PIID" ON "$SCHEMA$"."PROCESS_INST"("PI_COMPLETE_TIME", "PI_PROCESS_PTID", "PI_PIID");

CREATE INDEX "$SCHEMA$"."PI_STATE_AIID" ON "$SCHEMA$"."PROCESS_INST"("PI_STATE", "PI_PARENT_AIID");

RENAME EVENTS TO EVENTS_BACK;

ALTER TABLE "$SCHEMA$"."EVENTS_BACK" DROP PRIMARY KEY;

ALTER TABLE "$SCHEMA$"."EVENTS_BACK" DROP UNIQUE("QUEUEID", "EVENT_SEQ");

ALTER TABLE "$SCHEMA$"."EVENTS_BACK" ADD CONSTRAINT EVENT_BACK UNIQUE("QUEUEID", "EVENT_SEQ");

DROP INDEX "$SCHEMA$"."EVENT_CONTEXTID";

CREATE TABLE "$SCHEMA$"."EVENTS"(
"EVENTID" RAW(16) NOT NULL,
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"EVENT_TIME" DECIMAL(16,0) NOT NULL,
"EVENT_CODE" INTEGER NOT NULL,
"CONTEXTID" RAW(16) NOT NULL,
"ENGINETYPE" VARCHAR(75) NOT NULL,
"ENGINEID" RAW(16) NOT NULL,
"EVENT_TIME_FRAC" INTEGER NOT NULL,
"SHORT_DATA" RAW(1900),
CONSTRAINT "PK_EVENTS" PRIMARY KEY ("EVENTID"),
CONSTRAINT "EVENT_QUEUEID" UNIQUE("QUEUEID", "EVENT_SEQ")
) TABLESPACE $TABLESPACE$;

CREATE INDEX "$SCHEMA$"."EVENT_CONTEXTID" ON "$SCHEMA$"."EVENTS"("QUEUEID", "CONTEXTID");


CREATE TABLE "$SCHEMA$"."EVENT_DATA"(
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"DATA_SEQ" INTEGER NOT NULL,
"DATA" RAW(1900),
CONSTRAINT "PK_EVENT_DATA" PRIMARY KEY ("QUEUEID", "EVENT_SEQ", "DATA_SEQ")
) TABLESPACE $TABLESPACE$;

DROP TABLE "$SCHEMA$"."DELAYED_EVENTS" CASCADE CONSTRAINTS;

CREATE TABLE "$SCHEMA$"."DELAYED_EVENTS"(
"EVENTID" RAW(16) NOT NULL,
"QUEUEID" INTEGER NOT NULL,
"EVENT_SEQ" DECIMAL(16,0) NOT NULL,
"EVENT_TIME" DECIMAL(16,0) NOT NULL,
"EVENT_CODE" INTEGER NOT NULL,
"CONTEXTID" RAW(16) NOT NULL,
"ENGINETYPE" VARCHAR(75) NOT NULL,
"ENGINEID" RAW(16) NOT NULL,
"EVENT_TIME_FRAC" INTEGER NOT NULL,
"SHORT_DATA" RAW(1900),
"TRIAL_NUMBER" INTEGER DEFAULT 0 NOT NULL,
CONSTRAINT "PK_DEVENTS" PRIMARY KEY ("EVENTID"),
CONSTRAINT "DELAYED_QUEUEID" UNIQUE("QUEUEID", "EVENT_SEQ", "TRIAL_NUMBER")
) TABLESPACE $TABLESPACE$;

CREATE INDEX "$SCHEMA$"."DELAYED_CONTEXTID" ON "$SCHEMA$"."DELAYED_EVENTS"("CONTEXTID");

RENAME LOCK_TABLE TO EB_SYNC_TABLE;

CREATE TABLE "$SCHEMA$"."MQWF_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) TABLESPACE $TABLESPACE$;

CREATE TABLE "$SCHEMA$"."WMQI_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) TABLESPACE $TABLESPACE$;

CREATE TABLE "$SCHEMA$"."ICS_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) TABLESPACE $TABLESPACE$;

CREATE TABLE "$SCHEMA$"."CLEANUP_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) TABLESPACE $TABLESPACE$;

CREATE TABLE "$SCHEMA$"."NOTIFY_SYNC_TABLE"(
"LOCKER" INTEGER DEFAULT 0 NOT NULL
) TABLESPACE $TABLESPACE$;


CREATE TABLE "$SCHEMA$"."CXFLOWEVENTRECORDS"(
"SEQUENCENUMBER" DECIMAL(16,0) NOT NULL,
"EVENT" VARCHAR(255) NOT NULL,
"MONITORFLOWID" VARCHAR(255) NOT NULL,
"OUTBOUNDFLOWID" VARCHAR(255) NOT NULL,
"TIMESTAMP" DECIMAL(16,0) NOT NULL,
"COMPONENTNAME" VARCHAR(80) NOT NULL,
"COMPONENTTYPE" INTEGER,
CONSTRAINT "EVENTINDEX" UNIQUE("SEQUENCENUMBER")
) TABLESPACE $TABLESPACE$;

CREATE OR REPLACE TRIGGER "$SCHEMA$"."CX_INST" BEFORE INSERT ON "$SCHEMA$"."CXFLOWEVENTRECORDS" REFERENCING NEW AS NEW_REC FOR EACH ROW 
BEGIN
:NEW_REC.TIMESTAMP := (24 * 60 * 60 * 1000 * (SYSDATE - TO_DATE('1970-01-01 00:00:00','yyyy-mm-dd hh24:mi:ss')));
END;
/

ALTER TABLE "$SCHEMA$"."PROCESS_MODEL" ADD("PM_LAST_UPDATED" NUMBER(16) DEFAULT 0);

INSERT INTO $SCHEMA$.SYS_PROPERTIES VALUES('monitor.eventProcessor.count', '1');
